@@ -81,11 +81,11 @@ char rcsId_vmware[] =
 #define VMW_INNERSTRINGIFY(s) #s
 #define VMW_STRING(str) VMW_INNERSTRINGIFY(str)
 
-#define VMWARE_NAME "VMWARE"
-#define VMWARE_DRIVER_NAME "vmware"
-#define VMWARE_MAJOR_VERSION	10
-#define VMWARE_MINOR_VERSION	16
-#define VMWARE_PATCHLEVEL	8
+#define VMWARE_NAME "vmwlegacy"
+#define VMWARE_DRIVER_NAME "vmwlegacy"
+#define VMWARE_MAJOR_VERSION	11
+#define VMWARE_MINOR_VERSION	0
+#define VMWARE_PATCHLEVEL	0
 #define VMWARE_DRIVER_VERSION \
    (VMWARE_MAJOR_VERSION * 65536 + VMWARE_MINOR_VERSION * 256 + VMWARE_PATCHLEVEL)
 #define VMWARE_DRIVER_VERSION_STRING \
@@ -101,7 +101,7 @@ static const char VMWAREBuildStr[] = "VMware Guest X Server "
  * extra zero for the fourth digit.
  */
 #ifdef __GNUC__
-const char vm_svga_version[] __attribute__((section(".modinfo"),unused)) =
+const char vmwlegacy_drv_modinfo[] __attribute__((section(".modinfo"),unused)) =
     "version=" VMWARE_DRIVER_VERSION_STRING ".0";
 #endif
 
@@ -146,6 +146,13 @@ static PciChipsets VMWAREPciChipsets[] = {
     { -1,		       -1,		    RES_UNDEFINED }
 };
 
+#if HAVE_XORG_SERVER_1_7_0
+
+#define xf86LoaderReqSymLists(...) do {} while (0)
+#define LoaderRefSymLists(...) do {} while (0)
+
+#else
+
 static const char *vgahwSymbols[] = {
     "vgaHWGetHWRec",
     "vgaHWGetIOBase",
@@ -178,9 +185,11 @@ static const char *shadowfbSymbols[] = {
     NULL
 };
 
+#endif /* HAVE_XORG_SERVER_1_7_0 */
+
 #ifdef XFree86LOADER
-static XF86ModuleVersionInfo vmwareVersRec = {
-    "vmware",
+static XF86ModuleVersionInfo vmwlegacyVersRec = {
+    VMWARE_DRIVER_NAME,
     MODULEVENDORSTRING,
     MODINFOSTRING1,
     MODINFOSTRING2,
@@ -2012,7 +2021,7 @@ VMWAREProbe(DriverPtr drv, int flags)
 #endif
 
 
-_X_EXPORT DriverRec VMWARE = {
+_X_EXPORT DriverRec vmwlegacy = {
     VMWARE_DRIVER_VERSION,
     VMWARE_DRIVER_NAME,
     VMWAREIdentify,
@@ -2034,22 +2043,23 @@ _X_EXPORT DriverRec VMWARE = {
 };
 
 #ifdef XFree86LOADER
-static MODULESETUPPROTO(vmwareSetup);
+static MODULESETUPPROTO(vmwlegacySetup);
 
-_X_EXPORT XF86ModuleData vmwareModuleData = {
-    &vmwareVersRec,
-    vmwareSetup,
+_X_EXPORT XF86ModuleData vmwlegacyModuleData = {
+    &vmwlegacyVersRec,
+    vmwlegacySetup,
     NULL
 };
 
 static pointer
-vmwareSetup(pointer module, pointer opts, int *errmaj, int *errmin)
+vmwlegacySetup(pointer module, pointer opts, int *errmaj, int *errmin)
 {
     static Bool setupDone = FALSE;
 
     if (!setupDone) {
         setupDone = TRUE;
-        xf86AddDriver(&VMWARE, module, VMWARE_DRIVER_FUNC);
+
+        xf86AddDriver(&vmwlegacy, module, VMWARE_DRIVER_FUNC);
 
         LoaderRefSymLists(vgahwSymbols, fbSymbols, ramdacSymbols,
                           shadowfbSymbols, NULL);
